@@ -16,14 +16,16 @@ env
 
 print "======================================== Setup build"
 export color=no
+export CXXFLAGS="-Werror -Wno-unused-command-line-argument"
+
 rm -rf ${top}/install
 if [ "${maker}" = "make" ]; then
     make distclean
-    make config CXXFLAGS="-Werror" prefix=${top}/install \
+    make config prefix=${top}/install \
          || exit 10
 fi
 if [ "${maker}" = "cmake" ]; then
-    cmake -Dcolor=no -DCMAKE_CXX_FLAGS="-Werror" \
+    cmake -Dcolor=no \
           -DCMAKE_INSTALL_PREFIX=${top}/install \
           -Dgpu_backend=${gpu_backend} .. \
           || exit 12
