@@ -6,25 +6,31 @@ device=$2
 mydir=$(dirname $0)
 source ${mydir}/setup_env.sh
 
-print "======================================== Tests"
-
 # Instead of exiting on the first failed test (bash -e),
 # run all the tests and accumulate failures into $err.
 err=0
 
-cd test
 export OMP_NUM_THREADS=8
-./run_tests.py --blas1 --blas2 --blas3 --quick --xml ${top}/report-${maker}.xml
+
+print "======================================== Tests"
+cd test
+
+TESTER="./run_tests.py --quick"
+if [ "${device}" = "gpu_intel" ]; then
+    TESTER+=" --type s,c"
+fi
+
+${TESTER} --blas1 --blas2 --blas3 --xml ${top}/report-${maker}.xml
 (( err += $? ))
 
-./run_tests.py --batch-blas3           --quick --xml ${top}/report-${maker}-batch.xml
+${TESTER} --batch-blas3           --xml ${top}/report-${maker}-batch.xml
 (( err += $? ))
 
 # CUDA or HIP
-./run_tests.py --blas1-device --blas3-device --quick --xml ${top}/report-${maker}-device.xml
+${TESTER} --blas1-device --blas3-device --xml ${top}/report-${maker}-device.xml
 (( err += $? ))
 
-./run_tests.py --batch-blas3-device          --quick --xml ${top}/report-${maker}-batch-device.xml
+${TESTER} --batch-blas3-device          --xml ${top}/report-${maker}-batch-device.xml
 (( err += $? ))
 
 print "======================================== Smoke tests"
@@ -36,17 +42,20 @@ if [ "${maker}" = "make" ]; then
 fi
 if [ "${maker}" = "cmake" ]; then
     rm -rf build && mkdir build && cd build
-    # On some systems, CMake GNUInstallDirs uses lib, on others lib64.
-    lib="${top}/install/lib/blaspp;${top}/install/lib/lapackpp"
-    lib64="${top}/install/lib64/blaspp;${top}/install/lib64/lapackpp"
-    cmake "-DCMAKE_PREFIX_PATH=${lib};${lib64}" ..
+    cmake "-DCMAKE_PREFIX_PATH=${top}/install" ..
+fi
+
+if [ "${device}" = "gpu_intel" ]; then
+    TESTS="s c"
+else
+    TESTS="s d c z"
 fi
 
 make
-./example_gemm
+./example_gemm $TESTS
 (( err += $? ))
 
-./example_util
+./example_util $TESTS
 (( err += $? ))
 
 print "======================================== Finished test"
