@@ -40,7 +40,24 @@ void nrm2(
     blas::internal_set_device( queue.device() );
 
     // call low-level wrapper
-    internal::nrm2( n_, x, incx_, result, queue );
+    #if defined( BLAS_HAVE_ONEMKL )
+        sycl::queue syclq = queue.stream();
+        // check how the result scalar was allocated
+        auto result_ptr_type = sycl::get_pointer_type( result, syclq.get_context() );
+        // if result was outside SYCL/USM memory allocation, use device workspace
+        if (result_ptr_type == sycl::usm::alloc::unknown) {
+            // use preallocated device workspace (resizing if needed)
+            queue.work_ensure_size< char >( sizeof(scalar_t) );  // syncs if needed
+            real_type<scalar_t>* dev_work = (real_type<scalar_t>*)queue.work();
+            internal::nrm2( n_, x, incx_, dev_work, queue );
+            blas::device_memcpy( result, dev_work, 1, queue );
+        }
+        else {
+            internal::nrm2( n_, x, incx_, result, queue );
+        }
+    #else // other devices (CUDA/HIP)
+        internal::nrm2( n_, x, incx_, result, queue );
+    #endif
 #endif
 }
 
